@@ -34,7 +34,6 @@ import tensorflow.compat.v2 as tf
 from tensorflow_datasets.core import api_utils
 from tensorflow_datasets.core import constants
 from tensorflow_datasets.core import download
-from tensorflow_datasets.core import file_format_adapter
 from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import registered
@@ -56,8 +55,8 @@ REUSE_DATASET_IF_EXISTS = download.GenerateMode.REUSE_DATASET_IF_EXISTS
 GCS_HOSTED_MSG = """\
 Dataset %s is hosted on GCS. It will automatically be downloaded to your
 local data directory. If you'd instead prefer to read directly from our public
-GCS bucket (recommended if you're running on GCP), you can instead set
-data_dir=gs://tfds-data/datasets.
+GCS bucket (recommended if you're running on GCP), you can instead pass
+`try_gcs=True` to `tfds.load` or set `data_dir=gs://tfds-data/datasets`.
 """
 
 
@@ -349,7 +348,7 @@ class DatasetBuilder(object):
         download_config=download_config)
 
     # Create a tmp dir and rename to self._data_dir on successful exit.
-    with file_format_adapter.incomplete_dir(self._data_dir) as tmp_data_dir:
+    with utils.incomplete_dir(self._data_dir) as tmp_data_dir:
       # Temporarily assign _data_dir to tmp_data_dir to avoid having to forward
       # it to every sub function.
       with utils.temporary_assignment(self, "_data_dir", tmp_data_dir):
@@ -443,7 +442,7 @@ class DatasetBuilder(object):
     ```
 
     Args:
-      split: `tfds.core.SplitBase`, which subset(s) of the data to read. If None
+      split: `tfds.Split`, which subset(s) of the data to read. If None
         (default), returns all splits in a dict
         `<key: tfds.Split, value: tf.data.Dataset>`.
       batch_size: `int`, batch size. Note that variable-length features will
@@ -512,9 +511,6 @@ class DatasetBuilder(object):
       as_supervised,
   ):
     """as_dataset for a single split."""
-    if isinstance(split, six.string_types):
-      split = splits_lib.Split(split)
-
     wants_full_dataset = batch_size == -1
     if wants_full_dataset:
       batch_size = self.info.splits.total_num_examples or sys.maxsize
@@ -836,25 +832,12 @@ def _list_all_version_dirs(root_dir):
 
 
 class FileAdapterBuilder(DatasetBuilder):
-  """Base class for datasets with data generation based on file adapter.
-
-  `FileFormatAdapter`s are defined in
-  `tensorflow_datasets.core.file_format_adapter` and specify constraints on the
-  feature dictionaries yielded by example generators. See the class docstrings.
-  """
+  """Base class for datasets with data generation based on file adapter."""
 
   @utils.memoized_property
   def _example_specs(self):
     return self.info.features.get_serialized_info()
 
-  @utils.memoized_property
-  def _file_format_adapter(self):
-    # Load the format adapter (TF-Record,...)
-    # The file_format_adapter module will eventually be replaced by
-    # tfrecords_{reader,writer} modules.
-    file_adapter_cls = file_format_adapter.TFRecordExampleAdapter
-    return file_adapter_cls(self._example_specs)
-
   @property
   def _tfrecords_reader(self):
     return tfrecords_reader.Reader(self._data_dir, self._example_specs)
@@ -965,61 +948,6 @@ class FileAdapterBuilder(DatasetBuilder):
     ds = ds.map(decode_fn, num_parallel_calls=tf.data.experimental.AUTOTUNE)
     return ds
 
-  def _slice_split_info_to_instruction_dicts(self, list_sliced_split_info):
-    """Return the list of files and reading mask of the files to read."""
-    instruction_dicts = []
-    for sliced_split_info in list_sliced_split_info:
-      mask = splits_lib.slice_to_percent_mask(sliced_split_info.slice_value)
-
-      # Compute filenames from the given split
-      filepaths = list(sorted(self._build_split_filenames(
-          sliced_split_info.split_info)))
-
-      # Compute the offsets
-      if sliced_split_info.split_info.num_examples:
-        shard_id2num_examples = splits_lib.get_shard_id2num_examples(
-            sliced_split_info.split_info.num_shards,
-            sliced_split_info.split_info.num_examples,
-        )
-        mask_offsets = splits_lib.compute_mask_offsets(shard_id2num_examples)
-      else:
-        logging.warning(
-            "Statistics not present in the dataset. TFDS is not able to load "
-            "the total number of examples, so using the subsplit API may not "
-            "provide precise subsplits."
-        )
-        mask_offsets = [0] * len(filepaths)
-
-      for filepath, mask_offset in zip(filepaths, mask_offsets):
-        instruction_dicts.append({
-            "filepath": filepath,
-            "mask": mask,
-            "mask_offset": mask_offset,
-        })
-    return instruction_dicts
-
-  def _build_split_filenames(self, split_info):
-    """Construct the split filenames associated with the split info.
-
-    The filenames correspond to the pre-processed datasets files present in
-    the root directory of the dataset.
-
-    Args:
-      split_info: (SplitInfo) needed split.
-
-    Returns:
-      filenames: (list[str]) The list of filenames path corresponding to the
-        split info object
-    """
-
-    return naming.filepaths_for_dataset_split(
-        dataset_name=self.name,
-        split=split_info.name,
-        num_shards=split_info.num_shards,
-        data_dir=self._data_dir,
-        filetype_suffix=self._file_format_adapter.filetype_suffix,
-        )
-
 
 class GeneratorBasedBuilder(FileAdapterBuilder):
   """Base class for datasets with data generation based on dict generators.
@@ -1027,12 +955,8 @@ class GeneratorBasedBuilder(FileAdapterBuilder):
   `GeneratorBasedBuilder` is a convenience class that abstracts away much
   of the data writing and reading of `DatasetBuilder`. It expects subclasses to
   implement generators of feature dictionaries across the dataset splits
-  (`_split_generators`) and to specify a file type
-  (`_file_format_adapter`). See the method docstrings for details.
+  `_split_generators`. See the method docstrings for details.
 
-  `FileFormatAdapter`s are defined in
-  `tensorflow_datasets.core.file_format_adapter` and specify constraints on the
-  feature dictionaries yielded by example generators. See the class docstrings.
   """
 
   @abc.abstractmethod
