@@ -642,14 +642,6 @@ class DatasetBuilderReadTest(testing.TestCase):
         split=splits_lib.Split.TRAIN, as_supervised=True, batch_size=-1))
     self.assertEqual(x.shape[0], 20)
 
-  def test_is_dataset_v1(self):
-    # For backward compatibility, ensure that the returned dataset object
-    # has make_one_shot_iterator methods.
-    with tf.Graph().as_default():
-      ds = self.builder.as_dataset(split="train")
-      ds.make_one_shot_iterator()
-      ds.make_initializable_iterator()
-
   def test_autocache(self):
     # All the following should cache
 
