@@ -23,11 +23,14 @@ from __future__ import print_function
 import collections
 import os
 import subprocess as sp
+import zipfile
 
 from absl import logging
 import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets.core import utils
+from tensorflow_datasets.core.download import extractor
+from tensorflow_datasets.core.download import resource
 
 _ERR_MSG = """\
 To download Kaggle data through TFDS, follow the instructions to install the \
@@ -65,8 +68,7 @@ _KAGGLE_TYPES = {
 def _get_kaggle_type(competition_name):
   if "/" in competition_name:
     return _KAGGLE_TYPES["dataset"]
-  else:
-    return _KAGGLE_TYPES["competition"]
+  return _KAGGLE_TYPES["competition"]
 
 
 class KaggleFile(object):
@@ -168,6 +170,14 @@ class KaggleCompetitionDownloader(object):
     if self._kaggle_type.extra_flag:
       command.append(self._kaggle_type.extra_flag)
     _run_kaggle_command(command, self._competition_name)
+    # kaggle silently compresses some files to '.zip` files.
+    # TODO(tfds): use --unzip once supported by kaggle
+    # (https://github.com/Kaggle/kaggle-api/issues/9)
+    fpath = os.path.join(output_dir, fname + ".zip")
+    if zipfile.is_zipfile(fpath):
+      e = extractor.get_extractor()
+      with e.tqdm():
+        e.extract(fpath, resource.ExtractMethod.ZIP, output_dir).get()
     return os.path.join(output_dir, fname)
 
 
