@@ -74,6 +74,19 @@ class RegisteredTest(testing.TestCase):
     with self.assertRaisesWithPredicateMatch(ValueError, name):
       registered.builder(nonexistent)
 
+  def test_registered_cls(self):
+    name = "empty_dataset_builder"
+    self.assertIs(registered.builder_cls(name), EmptyDatasetBuilder)
+
+    nonexistent = "nonexistent_foobar_dataset"
+    with self.assertRaisesWithPredicateMatch(ValueError, "not found"):
+      registered.builder_cls(nonexistent)
+
+    with self.assertRaisesWithPredicateMatch(
+        ValueError, "`builder_cls` only accept the `dataset_name`"):
+      name_with_kwargs = "empty_dataset_builder/config:1.0.0"
+      registered.builder_cls(name_with_kwargs)
+
   def test_abstract(self):
     name = "unregistered_builder"
     self.assertEqual(name, UnregisteredBuilder.name)
@@ -110,6 +123,11 @@ class RegisteredTest(testing.TestCase):
                 "config": "conf1-attr", "data_dir": "bar"}
     self.assertEqual(expected, builder.kwargs)
 
+  def test_builder_camel_case(self):
+    fullname = "EmptyDatasetBuilder"
+    builder = registered.builder(fullname)
+    self.assertIsInstance(builder, EmptyDatasetBuilder)
+
   def test_load(self):
     name = "empty_dataset_builder/k1=1"
     data_dir = "foo"
