@@ -48,7 +48,8 @@ class GetDatasetFilesTest(testing.TestCase):
       'train': [3, 2, 3, 2, 3],  # 13 examples.
   }
 
-  PATH_PATTERN = '/foo/bar/mnist-train.tfrecord-0000%d-of-00005'
+  PATH_PATTERN = os.path.normpath(
+      '/foo/bar/mnist-train.tfrecord-0000%d-of-00005')
 
   def _get_files(self, instruction):
     file_instructions = tfrecords_reader._make_file_instructions_from_absolutes(
@@ -57,7 +58,8 @@ class GetDatasetFilesTest(testing.TestCase):
         absolute_instructions=[instruction],
     )
     for fi in file_instructions.file_instructions:
-      fi['filename'] = os.path.join('/foo/bar', fi['filename'])
+      fi['filename'] = os.path.normpath(
+          os.path.join('/foo/bar', fi['filename']))
     return file_instructions.file_instructions
 
   def test_no_skip_no_take(self):
@@ -409,8 +411,13 @@ class ReaderTest(testing.TestCase):
     self._write_tfrecord('train', 4, 'abcdefghijkl')
     fname_pattern = 'mnist-train.tfrecord-0000%d-of-00004'
     ds = self.reader.read_files(
-        [{'filename': fname_pattern % 1, 'skip': 0, 'take': -1},
-         {'filename': fname_pattern % 3, 'skip': 1, 'take': 1}],
+        tfrecords_reader.FileInstructions(
+            file_instructions=[
+                {'filename': fname_pattern % 1, 'skip': 0, 'take': -1},
+                {'filename': fname_pattern % 3, 'skip': 1, 'take': 1},
+            ],
+            num_examples_per_shard=None,
+        ),
         read_config=read_config_lib.ReadConfig(),
         shuffle_files=False)
     read_data = list(tfds.as_numpy(ds))
