@@ -37,7 +37,7 @@ class ShowExamplesTest(testing.TestCase):
     with testing.mock_data(num_examples=20):
       ds, ds_info = registered.load(
           'imagenet2012', split='train', with_info=True)
-    visualization.show_examples(ds_info, ds)
+    visualization.show_examples(ds, ds_info)
 
   # TODO(tfds): Should add test when there isn't enough examples (ds.take(3))
 
