@@ -16,6 +16,10 @@
 # Lint as: python3
 """Tests for Beans dataset."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 from tensorflow_datasets.image_classification import beans
 import tensorflow_datasets.testing as tfds_test
 
