@@ -16,6 +16,10 @@
 # Lint as: python3
 """Chexpert."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 import collections
 import csv
 import os
