@@ -16,6 +16,10 @@
 # Lint as: python3
 """Smallnorb dataset test."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 from tensorflow_datasets.image_classification import smallnorb
 import tensorflow_datasets.testing as tfds_test
 
