@@ -14,6 +14,11 @@
 # limitations under the License.
 
 # Lint as: python3
+
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 from tensorflow_datasets.image_classification import stanford_online_products
 import tensorflow_datasets.testing as tfds_test
 
