@@ -24,15 +24,14 @@ from tensorflow_datasets import core
 from tensorflow_datasets.core import download
 from tensorflow_datasets.core import decode
 from tensorflow_datasets.core import features
-from tensorflow_datasets.core import file_format_adapter as file_adapter
 from tensorflow_datasets.core import units
 from tensorflow_datasets.core import visualization
 from tensorflow_datasets.core.dataset_utils import as_numpy
 from tensorflow_datasets.core.download import GenerateMode
 from tensorflow_datasets.core.registered import builder
+from tensorflow_datasets.core.registered import builder_cls
 from tensorflow_datasets.core.registered import list_builders
 from tensorflow_datasets.core.registered import load
-from tensorflow_datasets.core.splits import percent
 from tensorflow_datasets.core.splits import Split
 from tensorflow_datasets.core.utils.gcs_utils import is_dataset_on_gcs
 from tensorflow_datasets.core.utils.read_config import ReadConfig
@@ -52,13 +51,12 @@ __all__ = [
     "decode",
     "download",
     "features",
-    "file_adapter",
     "units",
     "GenerateMode",
     "builder",
+    "builder_cls",
     "list_builders",
     "load",
-    "percent",
     "ReadConfig",
     "Split",
     "testing",
