@@ -16,10 +16,6 @@
 # Lint as: python3
 """Script that prints number of configs for a dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from absl import app
 from absl import flags
 
