@@ -16,6 +16,10 @@
 # Lint as: python3
 """Tests for Reddit dataset."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 from tensorflow_datasets import testing
 from tensorflow_datasets.summarization import reddit
 
